@@ -1,5 +1,5 @@
 #
-# $Id: IMDB.pm,v 1.51 2006/02/04 21:50:54 jveldhuis Exp $
+# $Id: IMDB.pm,v 1.54 2007/11/30 00:28:19 jveldhuis Exp $
 #
 # The IMDB file contains two packages:
 # 1. XMLTV::IMDB::Cruncher package which parses and manages IMDB "lists" files
@@ -33,7 +33,13 @@ use strict;
 
 package XMLTV::IMDB;
 
-our $VERSION = '0.6';
+#
+# HISTORY
+# .6 = what was here for the longest time
+# .7 = fixed file size est calculations
+#    = moviedb.info now includes _file_size_uncompressed values for each downloaded file
+#
+our $VERSION = '0.7';
 
 sub new
 {
@@ -174,7 +180,7 @@ sub basicVerificationOfIndexes($)
 
     # check that the imdbdir is invalid and up and running
     my $title="Army of Darkness";
-    my $year=1993;
+    my $year=1992;
 
     $self->openMovieIndex() || return("basic verification of indexes failed\n".
 				      "database index isn't readable");
@@ -1877,22 +1883,60 @@ sub dbinfoSave($)
     return(0);
 }
 
-sub dbinfoCalcEstimate($$$)
+sub dbinfoGetFileSize($$)
 {
-    my ($self, $key, $estimateSizePerEntry)=@_;
+    my ($self, $key)=@_;
     
     if ( !defined($self->{imdbListFiles}->{$key}) ) {
 	die ("invalid call");
     }
     my $fileSize=int(-s "$self->{imdbListFiles}->{$key}");
-    my $countEstimate=int($fileSize/$estimateSizePerEntry);
 
+    # if compressed, then attempt to run gzip -l
+    if ( $self->{imdbListFiles}->{$key}=~m/.gz$/) {
+	if ( open(my $fd, "gzip -l ".$self->{imdbListFiles}->{$key}."|") ) {
+	    # if parse fails, then defalt to wild ass guess of compression of 65%
+	    $fileSize=int(($fileSize*100)/(100-65));
+
+	    while(<$fd>) {
+		if ( m/^\s*\d+\s+(\d+)/ ) {
+		    $fileSize=$1;
+		}
+	    }
+	    close($fd);
+	}
+	else {
+	    # wild ass guess of compression of 65%
+	    $fileSize=int(($fileSize*100)/(100-65));
+	}
+    }
+    return($fileSize);
+}
+
+sub dbinfoCalcEstimate($$$)
+{
+    my ($self, $key, $estimateSizePerEntry)=@_;
+
+    my $fileSize=$self->dbinfoGetFileSize($key);
+
+    my $countEstimate=int($fileSize/$estimateSizePerEntry);
+    
     $self->dbinfoAdd($key."_list_file", $self->{imdbListFiles}->{$key});
-    $self->dbinfoAdd($key."_list_file_size", $fileSize);
+    $self->dbinfoAdd($key."_list_file_size", int(-s "$self->{imdbListFiles}->{$key}"));
+    $self->dbinfoAdd($key."_list_file_size_uncompressed", $fileSize);
     $self->dbinfoAdd($key."_list_count_estimate", $countEstimate);
     return($countEstimate);
 }
 
+sub dbinfoCalcBytesPerEntry($$$)
+{
+    my ($self, $key, $calcActualForThisNumber)=@_;
+
+    my $fileSize=$self->dbinfoGetFileSize($key);
+    
+    return(int($fileSize/$calcActualForThisNumber));
+}
+
 sub invokeStage($$)
 {
     my ($self, $stage)=@_;
@@ -1910,7 +1954,8 @@ sub invokeStage($$)
 	    return(1);
 	}
 	elsif ( abs($num - $countEstimate) > $countEstimate*.05 ) {
-	    $self->status("ARG estimate of $countEstimate for movies needs updating, found $num");
+	    my $better=$self->dbinfoCalcBytesPerEntry("movies", $num);
+	    $self->status("ARG estimate of $countEstimate for movies needs updating, found $num ($better bytes/entry)");
 	}
 	$self->dbinfoAdd("db_stat_movie_count", "$num");
 
@@ -1950,7 +1995,7 @@ sub invokeStage($$)
     elsif ( $stage == 2 ) {
 	$self->status("parsing Directors list for stage $stage..");
 
-	my $countEstimate=$self->dbinfoCalcEstimate("directors", 162);
+	my $countEstimate=$self->dbinfoCalcEstimate("directors", 204);
 
 	my $num=$self->readCastOrDirectors("Directors", $countEstimate, "$self->{imdbListFiles}->{directors}");
 	if ( $num < 0 ) {
@@ -1960,7 +2005,8 @@ sub invokeStage($$)
 	    return(1);
 	}
 	elsif ( abs($num - $countEstimate) > $countEstimate*.05 ) {
-	    $self->status("ARG estimate of $countEstimate for directors needs updating, found $num");
+	    my $better=$self->dbinfoCalcBytesPerEntry("directors", $num);
+	    $self->status("ARG estimate of $countEstimate for directors needs updating, found $num ($better bytes/entry)");
 	}
 	$self->dbinfoAdd("db_stat_director_count", "$num");
 
@@ -2016,7 +2062,7 @@ sub invokeStage($$)
 	$self->status("parsing Actors list for stage $stage..");
 
 	#print "re-reading movies into memory for reverse lookup..\n";
-	my $countEstimate=$self->dbinfoCalcEstimate("actors", 290);
+	my $countEstimate=$self->dbinfoCalcEstimate("actors", 378);
 
 	my $num=$self->readCastOrDirectors("Actors", $countEstimate, "$self->{imdbListFiles}->{actors}");
 	if ( $num < 0 ) {
@@ -2026,7 +2072,8 @@ sub invokeStage($$)
 	    return(1);
 	}
 	elsif ( abs($num - $countEstimate) > $countEstimate*.05 ) {
-	    $self->status("ARG estimate of $countEstimate for actors needs updating, found $num");
+	    my $better=$self->dbinfoCalcBytesPerEntry("actors", $num);
+	    $self->status("ARG estimate of $countEstimate for actors needs updating, found $num ($better bytes/entry)");
 	}
 	$self->dbinfoAdd("db_stat_actor_count", "$num");
 
@@ -2066,7 +2113,7 @@ sub invokeStage($$)
     elsif ( $stage == 4 ) {
 	$self->status("parsing Actresses list for stage $stage..");
 
-	my $countEstimate=$self->dbinfoCalcEstimate("actresses", 250);
+	my $countEstimate=$self->dbinfoCalcEstimate("actresses", 349);
 	my $num=$self->readCastOrDirectors("Actresses", $countEstimate, "$self->{imdbListFiles}->{actresses}");
 	if ( $num < 0 ) {
 	    if ( $num == -2 ) {
@@ -2075,7 +2122,8 @@ sub invokeStage($$)
 	    return(1);
 	}
 	elsif ( abs($num - $countEstimate) > $countEstimate*.05 ) {
-	    $self->status("ARG estimate of $countEstimate for actresses needs updating, found $num");
+	    my $better=$self->dbinfoCalcBytesPerEntry("actresses", $num);
+	    $self->status("ARG estimate of $countEstimate for actresses needs updating, found $num ($better bytes/entry)");
 	}
 	$self->dbinfoAdd("db_stat_actress_count", "$num");
 
@@ -2114,7 +2162,7 @@ sub invokeStage($$)
     }
     elsif ( $stage == 5 ) {
 	$self->status("parsing Genres list for stage $stage..");
-	my $countEstimate=$self->dbinfoCalcEstimate("genres", 60);
+	my $countEstimate=$self->dbinfoCalcEstimate("genres", 61);
 
 	my $num=$self->readMoviesOrGenres("Genres", $countEstimate, "$self->{imdbListFiles}->{genres}");
 	if ( $num < 0 ) {
@@ -2124,7 +2172,8 @@ sub invokeStage($$)
 	    return(1);
 	}
 	elsif ( abs($num - $countEstimate) > $countEstimate*.05 ) {
-	    $self->status("ARG estimate of $countEstimate for genres needs updating, found $num");
+	    my $better=$self->dbinfoCalcBytesPerEntry("genres", $num);
+	    $self->status("ARG estimate of $countEstimate for genres needs updating, found $num ($better bytes/entry)");
 	}
 	$self->dbinfoAdd("db_stat_genres_count", "$num");
 
@@ -2163,7 +2212,7 @@ sub invokeStage($$)
     }
     elsif ( $stage == 6 ) {
 	$self->status("parsing Ratings list for stage $stage..");
-	my $countEstimate=$self->dbinfoCalcEstimate("ratings", 60);
+	my $countEstimate=$self->dbinfoCalcEstimate("ratings", 63);
 
 	my $num=$self->readRatings($countEstimate, "$self->{imdbListFiles}->{ratings}");
 	if ( $num < 0 ) {
@@ -2173,7 +2222,8 @@ sub invokeStage($$)
 	    return(1);
 	}
 	elsif ( abs($num - $countEstimate) > $countEstimate*.05 ) {
-	    $self->status("ARG estimate of $countEstimate for ratings needs updating, found $num");
+	    my $better=$self->dbinfoCalcBytesPerEntry("ratings", $num);
+	    $self->status("ARG estimate of $countEstimate for ratings needs updating, found $num ($better bytes/entry)");
 	}
 	$self->dbinfoAdd("db_stat_ratings_count", "$num");
 
