@@ -1,6 +1,6 @@
 #!perl -w
 #
-# $Id: exe_wrap.pl,v 1.75 2007/10/01 13:27:27 rmeden Exp $
+# $Id: exe_wrap.pl,v 1.78 2008/02/17 07:09:00 rmeden Exp $
 # This is a quick XMLTV shell routing to use with the windows exe
 #
 # A single EXE is needed to allow sharing of modules and dlls of all the
@@ -69,7 +69,7 @@ print STDERR "Timezone is $ENV{TZ}\n" unless $opt_quiet;
 $cmd = shift || "";
 
 # --version (and abbreviations thereof)
-my $VERSION = '0.5.49';
+my $VERSION = '0.5.51';
 if (index('--version', $cmd) == 0 and length $cmd >= 3) {
     print "xmltv $VERSION\n";
     exit;
@@ -90,17 +90,8 @@ END
 #
 # some programs use a "share" directory
 #
-if ($cmd eq 'tv_grab_uk_rt'
- or $cmd eq 'tv_grab_au'
- or $cmd eq 'tv_grab_ch_bluewin'
- or $cmd eq 'tv_grab_ch_search'
- or $cmd eq 'tv_grab_be'
- or $cmd eq 'tv_grab_uk_bleb'
- or $cmd eq 'tv_grab_it'
- or $cmd eq 'tv_grab_na_dd',
+if ($cmd eq 'tv_grab_na_dd',
  or $cmd eq 'tv_grab_na_icons',
- or $cmd eq 'tv_grab_huro',
- or $cmd eq 'tv_grab_de_tvtoday'
  )
 {
     unless (grep(/^--share/i,@ARGV))  # don't add our --share if one supplied
